pyowlet
=========

Python library for connecting to the Owlet Unnoficial API hosted by Ayla Networks IOT Cloud

Protocol
--------

As the Owlet API is being worked out, notes are in PROTOCOL.md.

Usage
-----

To query your device's readings using the provided example file:

    python3 example.py user@example.com password

TODO
----

* TEST IT!
